@@ -1,11 +1,10 @@
 # @package      hubzero-mw-session
 # @file         apps.sh
 # @author       Nicholas J. Kisseberth <nkissebe@purdue.edu>
-# @copyright    Copyright (c) 2011 Purdue University. All rights reserved.
+# @copyright    Copyright (c) 2011-2012 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2011 Purdue University
-# All rights reserved.
+# Copyright (c) 2011-2012 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -23,8 +22,10 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# HUBzero is a registered trademark of Purdue University.
+# HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 
 PATH=$PATH:/apps/bin
 export PATH
+
+. /etc/apps-environ.sh
